@@ -141,5 +141,39 @@ class DogStatsd(object):
         except socket.error:
             log.exception("Error submitting metric")
 
+    def _escape_event_content(self, string):
+        return string.replace('\n', '\\n')
 
-statsd = DogStatsd()
+    def event(self, title, text, alert_type=None, aggregation_key=None, source_type_name=None, date_happened=None, priority=None, tags=None, hostname=None):
+        """
+        Send an event. Attributes are the same as the Event API.
+            http://docs.datadoghq.com/api/
+
+        >>> statsd.event('Man down!', 'This server needs assistance.')
+        >>> statsd.event('The web server restarted', 'The web server is up again', alert_type='success')
+        """
+        title = self._escape_event_content(title)
+        text = self._escape_event_content(text)
+        string = u'_e{%d,%d}:%s|%s' % (len(title), len(text), title, text)
+        if date_happened:
+            string = '%s|d:%d' % (string, date_happened)
+        if hostname:
+            string = '%s|h:%s' % (string, hostname)
+        if aggregation_key:
+            string = '%s|k:%s' % (string, aggregation_key)
+        if priority:
+            string = '%s|p:%s' % (string, priority)
+        if source_type_name:
+            string = '%s|s:%s' % (string, source_type_name)
+        if alert_type:
+            string = '%s|t:%s' % (string, alert_type)
+        if tags:
+            string = '%s|#%s' % (string, ','.join(tags))
+
+        if len(string) > 8 * 1024:
+            raise Exception(u'Event "%s" payload is too big (more that 8KB), event discarded' % title)
+
+        try:
+            self.socket.send(string)
+        except Exception:
+            log.exception(u'Error submitting event "%s"' % title)
